### Rasterio Tools

Raster I/O, processing, and analysis.

Core pages:

- [compute_ndvi](compute_ndvi.md)
- [clip_raster_with_shapefile](clip_raster_with_shapefile.md)
- [reproject_raster](reproject_raster.md)

More tools:

- [metadata_raster](metadata_raster.md)
- [get_raster_crs](get_raster_crs.md)
- [extract_band](extract_band.md)
- [raster_band_statistics](raster_band_statistics.md)
- [raster_histogram](raster_histogram.md)
- [resample_raster](resample_raster.md)
- [tile_raster](tile_raster.md)
- [raster_algebra](raster_algebra.md)
- [concat_bands](concat_bands.md)
- [weighted_band_sum](weighted_band_sum.md)
